==> terasoluna-batch4j-funcsample_2.0.0.2.zip: functionsample-batch/sources/jp/terasoluna/batch/functionsample/sample002/Sample002BLogic02.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.batch.functionsample.sample002;

import jp.terasoluna.fw.batch.openapi.BLogic;
import jp.terasoluna.fw.batch.openapi.BLogicResult;
import jp.terasoluna.fw.batch.openapi.JobContext;
import jp.terasoluna.fw.batch.openapi.ReturnCode;
import jp.terasoluna.fw.file.dao.FileLineWriter;

/**
 * rWlXWbNNXBiϒt@CgpWuj
 */
public class Sample002BLogic02 implements BLogic<Sample002NyukinData02, JobContext> {
 
    /**
     * t@Co͗psC^NXB
     * SpringɂCX^Xݒ肳B
     */
    private FileLineWriter<Sample002NyukinData02> fileLineWriter = null;
    
    public BLogicResult execute(Sample002NyukinData02 nyukinData, JobContext jobContext) {

    //z10,000ȏ̃f[^t@Cɏo
    int nyukin = nyukinData.getNyukin();
    if(nyukin >= 10000){
        //t@C֏
        fileLineWriter.printDataLine(nyukinData);
    }
    
    //rWlXWbNʃIuWFNgԋp
    BLogicResult result = new BLogicResult(ReturnCode.NORMAL_CONTINUE);
    return result;
    }
    
    /**
     * t@Co͗psC^NXݒ肷B
     * @param fileLineWriter t@Co͗psC^NX
     */
    public void setFileLineWriter(FileLineWriter<Sample002NyukinData02> fileLineWriter){
    this.fileLineWriter = fileLineWriter;
    }
}

==> terasoluna-batch4j-funcsample_2.0.3.1.zip: functionsample-batch/sources/jp/terasoluna/batch/functionsample/sample002/Sample002BLogic02.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.batch.functionsample.sample002;

import jp.terasoluna.fw.batch.openapi.BLogic;
import jp.terasoluna.fw.batch.openapi.BLogicResult;
import jp.terasoluna.fw.batch.openapi.JobContext;
import jp.terasoluna.fw.batch.openapi.ReturnCode;
import jp.terasoluna.fw.file.dao.FileLineWriter;

/**
 * rWlXWbNNXBiϒt@CgpWuj
 */
public class Sample002BLogic02 implements
                              BLogic<Sample002NyukinData02, JobContext> {

    /**
     * t@Co͗psC^NXB SpringɂCX^Xݒ肳B
     */
    private FileLineWriter<Sample002NyukinData02> fileLineWriter = null;

    public BLogicResult execute(Sample002NyukinData02 nyukinData,
            JobContext jobContext) {

        // z10,000ȏ̃f[^t@Cɏo
        int nyukin = nyukinData.getNyukin();
        if (nyukin >= 10000) {
            // t@C֏
            fileLineWriter.printDataLine(nyukinData);
        }

        // rWlXWbNʃIuWFNgԋp
        BLogicResult result = new BLogicResult(ReturnCode.NORMAL_CONTINUE);
        return result;
    }

    /**
     * t@Co͗psC^NXݒ肷B
     * @param fileLineWriter t@Co͗psC^NX
     */
    public void setFileLineWriter(
            FileLineWriter<Sample002NyukinData02> fileLineWriter) {
        this.fileLineWriter = fileLineWriter;
    }
}
